SPECIES
=======

**Spectral and Photometric Examination Code for Investigating Exoplanet and Substellar atmospheres**

.. image:: https://badge.fury.io/py/species.svg
    :target: https://badge.fury.io/py/species

.. image:: https://img.shields.io/badge/Python-3.6%2C%203.7-yellow.svg?style=flat
    :target: https://pypi.python.org/pypi/species

.. image:: https://travis-ci.org/tomasstolker/species.svg?branch=master
    :target: https://travis-ci.org/tomasstolker/species

.. image:: https://readthedocs.org/projects/species/badge/?version=latest
    :target: http://species.readthedocs.io/en/latest/?badge=latest

.. image:: https://coveralls.io/repos/github/tomasstolker/species/badge.svg
   :target: https://coveralls.io/github/tomasstolker/species

.. image:: https://www.codefactor.io/repository/github/tomasstolker/species/badge
   :target: https://www.codefactor.io/repository/github/tomasstolker/species

.. image:: https://img.shields.io/badge/License-GPLv3-blue.svg
    :target: https://github.com/tomasstolker/species/blob/master/LICENSE

SPECIES is a toolkit for analyzing spectral and photometric data of planetary and substellar objects.

Documentation
-------------

Documentation can be found at `http://species.readthedocs.io <http://species.readthedocs.io>`_.

Attribution
-----------

Please cite Stolker et al. in prep. whenever results from SPECIES are used in a publication. Please also make sure to give credit the relevant papers regarding the use of the publicly available data that SPECIES is using, such as the photometric and spectral libraries, atmospheric models, filter transmission curves, and photometry of individual objects. More details will follow.

License
-------

Copyright 2018 Tomas Stolker

SPECIES is free software and distributed under the GNU General Public License v3.